@@ -1,14 +1,11 @@
 #!/usr/bin/env python
 import os
-import click
 from click import echo, secho, pass_context, command, argument, option
 
 import hjson
 import logging
 import subprocess
-from collections import OrderedDict
-import botocore.session
-import dateutil
+
 
 from nextcode.credentials import generate_credential_struct, creds_to_dict
 from nextcode.packagelocal import package_and_upload
@@ -112,6 +109,9 @@ def run(
         params = manifest.get('params', {})
         if not credentials_map:  # If credentials were not passed via th commandline
             credentials_map = manifest.get('credentials', {})
+        storage_type = storage_type or manifest.get('storage_type')
+        dedicated_storage_size = dedicated_storage_size or manifest.get('dedicated_storage_size')
+
     credentials_struct = generate_credential_struct(credentials_map)
 
     features = {f.split('=')[0]:f.split('=')[-1] for f in features}
